======
badX12
======


.. image:: https://img.shields.io/pypi/v/badX12.svg
        :target: https://pypi.python.org/pypi/badX12

.. image:: https://img.shields.io/travis/git-albertomarin/badX12.svg
        :target: https://travis-ci.org/git-albertomarin/badX12

.. image:: https://readthedocs.org/projects/badX12/badge/?version=latest
        :target: https://badX12.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




A Python Library for parsing ANSI ASC X12 files.


* Free software: MIT license
* Documentation: https://badX12.readthedocs.io.


Features
--------

* TODO

Disclaimer
_______
Please be aware that all edi files within the test directory are examples provided by x12.org

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
